==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/HeaderSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderSeparatorDescription } from "./HeaderSeparatorDescription";
/**
 * @hidden
 */
export let HeaderSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderSeparatorDescriptionMetadata.a == null) {
                HeaderSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderSeparatorDescriptionMetadata.c(HeaderSeparatorDescriptionMetadata.a);
            }
            if (a.j(HeaderSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.y(HeaderSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            HeaderSeparatorDescriptionMetadata.b(a);
            a.aa("HeaderSeparator", () => new HeaderSeparatorDescription());
            a.z("HeaderSeparator", HeaderSeparatorDescriptionMetadata.a);
        }
    }
    HeaderSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(HeaderSeparatorDescriptionMetadata, 'HeaderSeparatorDescriptionMetadata');
    HeaderSeparatorDescriptionMetadata.a = null;
    return HeaderSeparatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/HeaderSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderSeparatorDescription } from "./HeaderSeparatorDescription";
/**
 * @hidden
 */
export let HeaderSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeaderSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (HeaderSeparatorDescriptionMetadata.a == null) {
                HeaderSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeaderSeparatorDescriptionMetadata.c(HeaderSeparatorDescriptionMetadata.a);
            }
            if (a.k(HeaderSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(HeaderSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            HeaderSeparatorDescriptionMetadata.b(a);
            a.ac("HeaderSeparator", () => new HeaderSeparatorDescription());
            a.ab("HeaderSeparator", HeaderSeparatorDescriptionMetadata.a);
        }
    }
    HeaderSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(HeaderSeparatorDescriptionMetadata, 'HeaderSeparatorDescriptionMetadata');
    HeaderSeparatorDescriptionMetadata.a = null;
    return HeaderSeparatorDescriptionMetadata;
})();
